@@ -2,13 +2,13 @@ use strict;
 use warnings FATAL => 'all';
 
 package HTML::Tested::List::Table;
+use Carp;
 
-sub init {}
+sub new { bless {}, shift(); }
 
-sub render {
-	my ($self, $the_list, $caller, $stash, $id) = @_;
+sub init {
+	my ($self, $the_list, $parent) = @_;
 	my $c = $the_list->containee;
-	my $ln = $the_list->name;
 	my (@cols, @names);
 	for my $w (@{ $c->Widgets_List }) {
 		my $n = $w->name;
@@ -17,14 +17,22 @@ sub render {
 		push @cols, $ct;
 		push @names, $n;
 	}
-	return unless @cols;
+	confess "No columns found!" unless @cols;
+	$self->{_cols} = \@cols;
+	$self->{_names} = \@names;
+}
+
+sub render {
+	my ($self, $the_list, $caller, $stash, $id) = @_;
+	my ($cols, $names) = ($self->{_cols}, $self->{_names});
+	my $ln = $the_list->name;
 	my $res = "<table>\n<tr>\n";
-	for my $t (@cols) {
+	for my $t (@$cols) {
 		$res .= "<th>$t</th>\n";
 	}
 	for my $r (@{ $stash->{ $ln } }) {
 		$res .= "</tr>\n<tr>\n";
-		for my $n (@names) {
+		for my $n (@$names) {
 			$res .= "<td>" . $r->{$n} . "</td>\n";
 		}
 	}
